'use strict';

class DingusError extends Error {
  constructor(...args) {
    super(...args);
    Error.captureStackTrace(DingusError);
  }

  get name() {
    return this.constructor.name;
  }
}

class ResponseError extends DingusError {
  constructor(errorResponse, details) {
    super(errorResponse.errorMessage);
    Object.assign(this, {
      ...errorResponse,
      ...(details && { details }),
    });
    delete this.stack; // No need for stacktrace here.
  }
}

class RouterError extends DingusError {
  constructor(...args) {
    super(...args);
    delete this.stack;
  }
}

class RouterNoPathError extends RouterError {
}

class RouterNoMethodError extends RouterError {
}

module.exports = {
  DingusError,
  ResponseError,
  RouterError,
  RouterNoPathError,
  RouterNoMethodError,
};
