'use strict';

const parameters = new Map();
/**
 * De-duplicating factory of minimal-objects to track the named-parameter parts of path definitions.
 *
 * @property {String} parameter
 */
class PathParameter extends null {
  static #parameters = parameters;

  constructor(parameter) {
    if (!parameter || typeof(parameter) !== 'string') {
      throw new RangeError('parameter must be string');
    }

    if (PathParameter.#parameters.has(parameter)) {
      return PathParameter.#parameters.get(parameter); // NOSONAR
    }

    const pathParameter = Object.create(PathParameter.prototype);
    pathParameter.parameter = parameter;
    Object.freeze(pathParameter);
    PathParameter.#parameters.set(parameter, pathParameter);
    return pathParameter; // NOSONAR
  }

  /**
   * @returns {String}
   */
  toString() {
    return this.parameter;
  }

  /**
   * @returns {String}
   */
  toJSON() {
    return this.parameter;
  }

  /**
   * Clear the de-duplication table, for tests.
   */
  static _flush() {
    PathParameter.#parameters.clear();
  }
}

module.exports = PathParameter;
