/* eslint-env mocha */
'use strict';

const assert = require('assert');
const PathParameter = require('../../../lib/router/path-parameter');

describe('PathParameter', function () {
  beforeEach(function () {
    PathParameter._flush();
  });

  it('requires a parameter', function () {
    assert.throws(() => new PathParameter(), RangeError);
  });

  it('requires parameter be a string', function () {
    assert.throws(() => new PathParameter({}), RangeError);
  });

  it('creates a parameter object', function () {
    const p = new PathParameter('foo');
    assert(p instanceof PathParameter);
    assert.strictEqual(p.parameter, 'foo');
  });

  it('duplicate parameters are the same object', function () {
    const p1 = new PathParameter('foo');
    const p2 = new PathParameter('foo');
    assert.strictEqual(p1, p2);
    assert(Object.is(p1, p2));
  });

  it('shows itself', function () {
    const p = new PathParameter('foo');
    assert.strictEqual(`${p}`, 'foo');
  });

  it('serializes', function () {
    const p = new PathParameter(':foo');
    const result = JSON.stringify(p);
    assert.strictEqual(result, '":foo"');
  });

  it('parameters are immutable', function () {
    const p = new PathParameter('foo');
    assert.throws(() => p.parameter = 'bar', TypeError);
  });

}); // PathParameter
